@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dashboard-extension.c,v 1.9.2.2 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: ephy-dashboard-extension.c,v 1.9.2.3 2005/01/20 15:41:34 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -142,9 +142,9 @@ load_status_cb (EphyTab *tab,
 			g_object_unref (persist);
 
 			DashboardSendCluePacket (
-				EPIPHANY_FRONTEND_IDENTIFIER,
+				(const xmlChar*) EPIPHANY_FRONTEND_IDENTIFIER,
 				ephy_tab_get_visibility(tab), /* focused */
-				location, /* context */
+				(const xmlChar*) location, /* context */
 				location, "url", 10,
 				page_title, "title", 10,
 				content, "htmlblock", 10,
@@ -157,9 +157,9 @@ load_status_cb (EphyTab *tab,
 			LOG ("Page not bookmarked, sending only location and title")
 
 			DashboardSendCluePacket (
-				EPIPHANY_FRONTEND_IDENTIFIER,
+				(const xmlChar*) EPIPHANY_FRONTEND_IDENTIFIER,
 				ephy_tab_get_visibility(tab), /* focused */
-				location, /* context */
+				(const xmlChar*) location, /* context */
 				location, "url", 10,
 				page_title, "title", 10,
 				NULL);
