@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: error-viewer.c,v 1.11 2004/03/15 20:39:38 adamh Exp $
+ *  $Id: error-viewer.c,v 1.13.2.2 2004/10/05 12:05:43 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,6 +64,12 @@ enum
 	N_COLUMNS
 };
 
+/* glade callbacks */
+void error_viewer_clear_cb (GtkWidget *button,
+			    ErrorViewer *dialog);
+void error_viewer_close_cb (GtkWidget *button,
+			    ErrorViewer *dialog);
+
 static void error_viewer_class_init	(ErrorViewerClass *klass);
 static void error_viewer_init		(ErrorViewer *dialog);
 static void error_viewer_finalize	(GObject *object);
@@ -197,7 +203,6 @@ build_ui (ErrorViewer *dialog)
 	GdkPixbuf *icon;
 	GtkListStore *store;
 	GtkTreeView *treeview;
-	GtkTreeViewColumn *col;
 	GtkCellRenderer *renderer;
 	ErrorViewerPrivate *priv = dialog->priv;
 
@@ -248,6 +253,7 @@ build_ui (ErrorViewer *dialog)
 				       GTK_ICON_SIZE_MENU,
 				       NULL);
 	gtk_window_set_icon (GTK_WINDOW (priv->window), icon);
+	g_object_unref (icon);
 }
 
 static void
@@ -269,7 +275,7 @@ error_viewer_init (ErrorViewer *dialog)
 static void
 error_viewer_finalize (GObject *object)
 {
-	ErrorViewer *dialog = ERROR_VIEWER (object);
+//	ErrorViewer *dialog = ERROR_VIEWER (object);
 
 	/* FIXME: Free TreeView stuff? */
 
@@ -281,6 +287,8 @@ error_viewer_clear_cb (GtkWidget *button,
 		       ErrorViewer *dialog)
 {
 	gtk_list_store_clear (GTK_LIST_STORE (dialog->priv->model));
+
+	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (dialog->priv->treeview));
 }
 
 void
@@ -309,12 +317,16 @@ update_cursor (ErrorViewer *dialog)
 
 void error_viewer_use (ErrorViewer *dialog)
 {
+	g_return_if_fail (IS_ERROR_VIEWER (dialog));
+
 	dialog->priv->num_active++;
 	update_cursor (dialog);
 }
 
 void error_viewer_unuse (ErrorViewer *dialog)
 {
+	g_return_if_fail (IS_ERROR_VIEWER (dialog));
+
 	dialog->priv->num_active--;
 	update_cursor (dialog);
 }
