@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerConsoleListener.cpp,v 1.8 2004/06/14 11:56:28 chpe Exp $
+ *  $Id: ErrorViewerConsoleListener.cpp,v 1.8.2.1 2004/11/15 15:08:50 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +27,9 @@
 
 #include "ErrorViewerConsoleListener.h"
 
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
 
