@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.2 2004/06/14 11:56:28 chpe Exp $
+ *  $Id: mozilla-helpers.cpp,v 1.2.2.1 2004/11/15 15:08:50 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +26,9 @@
 #include <gtkmozembed.h>
 #include <gtkmozembed_internal.h>
 
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsCOMPtr.h>
 #include <nsIChannel.h>
 #include <nsIHttpChannel.h>
