@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.13.2.4 2004/10/11 17:27:11 chpe Exp $
+ *  $Id: sgml-validator.c,v 1.13.2.5 2005/01/20 15:41:34 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -328,7 +328,7 @@ save_source_completed_cb (EphyEmbedPersist *persist,
 {
 	const char *dest;
 	char *location;
-	char *dest_utf8;
+	char *dest_utf8 = NULL;
 	gboolean is_xml;
 	unsigned int num_errors = 0;
 	OpenSPThreadCBData *data;
