@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.10 2004/08/06 02:02:08 adamh Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.10.2.2 2005/01/20 15:41:35 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,8 @@
 #include <gmodule.h>
 #include <libxml/tree.h>
 
+#include <string.h>
+
 #define EPHY_GESTURES_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_GESTURES_EXTENSION, EphyGesturesExtensionPrivate))
 
 struct EphyGesturesExtensionPrivate
@@ -114,13 +116,13 @@ load_one_gesture (EphyGesturesExtension *extension,
 
 	for (child = node->children; child != NULL; child = child->next)
 	{
-		if (xmlStrEqual (child->name, "sequence"))
+		if (xmlStrEqual (child->name, (const xmlChar*) "sequence"))
 		{
 			s = xmlNodeGetContent (child);
 
 			sequences = g_slist_prepend (sequences, s);
 		}
-		else if (xmlStrEqual (child->name, "action"))
+		else if (xmlStrEqual (child->name, (const xmlChar*) "action"))
 		{
 			if (action == NULL)
 			{
@@ -143,7 +145,7 @@ load_one_gesture (EphyGesturesExtension *extension,
 	{
 		g_hash_table_insert (extension->priv->gestures,
 				     g_strdup (l->data),
-				     g_strdup (action));
+				     g_strdup ((char*)action));
 		xmlFree (l->data);
 	}
 
@@ -157,7 +159,7 @@ load_gestures (EphyGesturesExtension *extension,
 {
 	xmlDocPtr doc;
 	xmlNodePtr root, child;
-	xmlChar *tmp;
+	xmlChar *tmp = NULL;
 
 	if (g_file_test (filename, G_FILE_TEST_EXISTS) == FALSE)
 	{
@@ -173,7 +175,7 @@ load_gestures (EphyGesturesExtension *extension,
 	}
 
 	root = xmlDocGetRootElement (doc);
-	if (root == NULL || strcmp (root->name, EPHY_GESTURES_XML_ROOT) != 0)
+	if (root == NULL || strcmp ((char*)root->name, EPHY_GESTURES_XML_ROOT) != 0)
 	{
 		g_warning ("Gestures definitions file %s has wrong format '%s'"
 		           "(expected " EPHY_GESTURES_XML_ROOT ")\n",
@@ -181,8 +183,8 @@ load_gestures (EphyGesturesExtension *extension,
 		goto out;
 	}
 
-	tmp = xmlGetProp (root, "version");
-	if (tmp  == NULL || strcmp (tmp, EPHY_GESTURES_XML_VERSION) != 0)
+	tmp = xmlGetProp (root, (const xmlChar*) "version");
+	if (tmp  == NULL || strcmp ((char*) tmp, (char*) EPHY_GESTURES_XML_VERSION) != 0)
 	{
 		g_warning ("Gestures definitions file %s has wrong format version %s"
 			   "(expected " EPHY_GESTURES_XML_VERSION ")\n",
@@ -192,7 +194,7 @@ load_gestures (EphyGesturesExtension *extension,
 
 	for (child = root->children; child != NULL; child = child->next)
 	{
-		if (xmlStrEqual (child->name, "gesture"))
+		if (xmlStrEqual (child->name, (const xmlChar*) "gesture"))
 		{
 			load_one_gesture (extension, child);
 		}
@@ -282,8 +284,7 @@ gesture_performed_cb (EphyGesture *gesture,
 	else
 	{
 		GtkUIManager *manager;
-		GtkAction *action = NULL;
-		GList *action_groups, *l;
+		GtkAction *action;
 		
 		manager = GTK_UI_MANAGER (window->ui_merge);
 		
@@ -299,12 +300,11 @@ gesture_performed_cb (EphyGesture *gesture,
 	}
 }
 
-static gint
+static gboolean
 dom_mouse_down_cb (EphyEmbed *embed,
 		   EphyEmbedEvent *event,
 		   EphyGesturesExtension *extension)
 {
-	EphyTab *tab;
         EmbedEventContext context;
 	EphyEmbedEventType type;
 	gint handled = FALSE;
@@ -318,13 +318,12 @@ dom_mouse_down_cb (EphyEmbed *embed,
 		EphyGesture *gesture;
 		GtkWidget *toplevel;
 		EphyTab *tab;
-		guint x, y;
 
 		tab = ephy_tab_for_embed (embed);
-		g_return_if_fail (EPHY_IS_TAB (tab));
+		g_return_val_if_fail (EPHY_IS_TAB (tab), handled);
 
 		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
-		g_return_if_fail (toplevel != NULL);
+		g_return_val_if_fail (toplevel != NULL, handled);
 
 		gesture = ephy_gesture_new (toplevel, event);
 
