@@ -22,7 +22,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.20.2.2 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.20.2.4 2004/11/07 20:47:20 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -503,8 +503,9 @@ treeview_info_page_show_popup (TreeviewInfoPage *page)
 
 	widget = gtk_ui_manager_get_widget (dialog->priv->manager,
 					    page->popup_path);
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
+	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0,
 			gtk_get_current_event_time ());
+	gtk_menu_shell_select_first (GTK_MENU_SHELL (widget), FALSE);
 
 	return TRUE;
 }
@@ -1134,8 +1135,49 @@ enum
 	COL_LINK_REL
 };
 
+static char *
+links_get_selected_link_url (LinksInfoPage *page)
+{
+	TreeviewInfoPage *tpage = (TreeviewInfoPage *) page;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	char *address = NULL;
+
+	if (gtk_tree_selection_get_selected (tpage->selection, &model, &iter))
+	{
+		gtk_tree_model_get (model, &iter,
+				    COL_LINK_URL, &address,
+				    -1);
+	}
+
+	return address;
+}
+
+static void
+links_copy_link_address_cb (GtkAction *action,
+			    LinksInfoPage *page)
+{
+	char *address;
+
+	address = links_get_selected_link_url (page);
+	if (address == NULL) return;
+
+	gtk_clipboard_set_text (gtk_clipboard_get (GDK_NONE),
+				address, -1);
+	gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_PRIMARY),
+				address, -1);
+
+	g_free (address);
+}
+
 static GtkActionEntry links_action_entries[] =
 {
+	{ "CopyLinkAddress", 
+	  GTK_STOCK_COPY,
+	  N_("_Copy Link Address"),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (links_copy_link_address_cb) },
 };
 
 static void
@@ -1204,7 +1246,7 @@ links_info_page_construct (InfoPage *ipage)
 	tpage->selection = selection;
 	tpage->treeview = treeview;
 
-//	treeview_info_page_construct (ipage);
+	treeview_info_page_construct (ipage);
 }
 
 static void
